const fs = require('fs');
const express = require('express');
const http = require('http');
const { Server } = require('socket.io');
const compression = require('compression');

const events = Object.fromEntries(
	fs.readdirSync('./src/event')
		.map(event => [event.slice(0, -3), require('./src/event/' + event)])
);

const PORT = process.env.PORT || 3435;

const app = express();
app.use(compression());
const server = http.createServer(app);
const io = new Server(server, {
	cors: {
		origin: true,
	},
});

io.cache = {};

io.on('connection', (socket) => {
	for (let event in events) {
		socket.on(event, (msg, callback) =>
			events[event](msg, callback, socket, io)
		);
	}
	socket.on('disconnect', reason => {
		let sockets = io.cache[socket.username];
		if (sockets)
			sockets.splice(sockets.indexOf(socket.id), 1);
	})
});

server.listen(PORT, () => {
	console.log('server running on port ' + PORT);
});

app.use(express.static('client'));
